//$Id: text-field-canvas.h,v 1.3 2001/10/18 20:41:43 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_TEXT_FIELD_CANVAS_H
#define GUIKACHU_FORM_EDITOR_TEXT_FIELD_CANVAS_H

#include "form-editor/text-field.h"
#include "form-editor/canvasitem.h"

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class TextFieldCanvasItem: public CanvasItem
	    {
		Widgets::TextField *widget;
		Gnome::CanvasGroup *group;
	    public:
		TextFieldCanvasItem (Widgets::TextField    *widget,
				     GUI::FormEditor::Form *form);
	    protected:
		virtual void update ();
		virtual void get_bounds (int &x1, int &y1,
					 int &x2, int &y2);
	    };
	}
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_TEXT_FIELD_CANVAS_H */
